==> v4.4.6.tar.gz: doomretro-4.4.6/src/m_controls.h <==
/*
========================================================================

                           D O O M  R e t r o
         The classic, refined DOOM source port. For Windows PC.

========================================================================

  Copyright © 1993-2022 by id Software LLC, a ZeniMax Media company.
  Copyright © 2013-2022 by Brad Harding <mailto:brad@doomretro.com>.

  DOOM Retro is a fork of Chocolate DOOM. For a list of credits, see
  <https://github.com/bradharding/doomretro/wiki/CREDITS>.

  This file is a part of DOOM Retro.

  DOOM Retro is free software: you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation, either version 3 of the license, or (at your
  option) any later version.

  DOOM Retro is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with DOOM Retro. If not, see <https://www.gnu.org/licenses/>.

  DOOM is a registered trademark of id Software LLC, a ZeniMax Media
  company, in the US and/or other countries, and is used without
  permission. All other trademarks are the property of their respective
  holders. DOOM Retro is in no way affiliated with nor endorsed by
  id Software.

========================================================================
*/

#if !defined(__M_CONTROLS_H__)
#define __M_CONTROLS_H__

#include "doomkeys.h"

extern int  keyboardalwaysrun;
extern int  keyboardautomap;
extern int  keyboardclearmark;
extern int  keyboardfollowmode;
extern int  keyboardgrid;
extern int  keyboardmark;
extern int  keyboardmaxzoom;
extern int  keyboardrotatemode;
extern int  keyboardzoomin;
extern int  keyboardzoomout;
extern int  keyboardback;
extern int  keyboardback2;
extern int  keyboardconsole;
extern int  keyboardfire;
extern int  keyboardforward;
extern int  keyboardforward2;
extern int  keyboardjump;
extern int  keyboardleft;
extern int  keyboardmenu;
extern int  keyboardmouselook;
extern int  keyboardnextweapon;
extern int  keyboardprevweapon;
extern int  keyboardright;
extern int  keyboardrun;
extern int  keyboardscreenshot;
extern int  keyboardstrafe;
extern int  keyboardstrafeleft2;
extern int  keyboardstrafeleft;
extern int  keyboardstraferight2;
extern int  keyboardstraferight;
extern int  keyboarduse;
extern int  keyboarduse2;
extern int  keyboardweapon1;
extern int  keyboardweapon2;
extern int  keyboardweapon3;
extern int  keyboardweapon4;
extern int  keyboardweapon5;
extern int  keyboardweapon6;
extern int  keyboardweapon7;

extern int  mouseback;
extern int  mousefire;
extern int  mouseforward;
extern int  mousejump;
extern int  mouseleft;
extern int  mousemouselook;
extern int  mousenextweapon;
extern int  mouseprevweapon;
extern int  mouseright;
extern int  mouserun;
extern int  mousescreenshot;
extern int  mousestrafe;
extern int  mousestrafeleft;
extern int  mousestraferight;
extern int  mouseuse;
extern int  mouseweapon1;
extern int  mouseweapon2;
extern int  mouseweapon3;
extern int  mouseweapon4;
extern int  mouseweapon5;
extern int  mouseweapon6;
extern int  mouseweapon7;

extern int  gamecontrolleralwaysrun;
extern int  gamecontrollerautomap;
extern int  gamecontrollerclearmark;
extern int  gamecontrollerfollowmode;
extern int  gamecontrollergrid;
extern int  gamecontrollermark;
extern int  gamecontrollermaxzoom;
extern int  gamecontrollerrotatemode;
extern int  gamecontrollerzoomin;
extern int  gamecontrollerzoomout;
extern int  gamecontrollerback;
extern int  gamecontrollerconsole;
extern int  gamecontrollerfire;
extern int  gamecontrollerforward;
extern int  gamecontrollerjump;
extern int  gamecontrollerleft;
extern int  gamecontrollermenu;
extern int  gamecontrollermouselook;
extern int  gamecontrollernextweapon;
extern int  gamecontrollerprevweapon;
extern int  gamecontrollerright;
extern int  gamecontrollerrun;
extern int  gamecontrollerstrafe;
extern int  gamecontrollerstrafeleft;
extern int  gamecontrollerstraferight;
extern int  gamecontrolleruse;
extern int  gamecontrolleruse2;
extern int  gamecontrollerweapon1;
extern int  gamecontrollerweapon2;
extern int  gamecontrollerweapon3;
extern int  gamecontrollerweapon4;
extern int  gamecontrollerweapon5;
extern int  gamecontrollerweapon6;
extern int  gamecontrollerweapon7;

#endif

==> v4.5.1.tar.gz: doomretro-4.5.1/src/m_controls.h <==
/*
========================================================================

                           D O O M  R e t r o
         The classic, refined DOOM source port. For Windows PC.

========================================================================

  Copyright © 1993-2022 by id Software LLC, a ZeniMax Media company.
  Copyright © 2013-2022 by Brad Harding <mailto:brad@doomretro.com>.

  DOOM Retro is a fork of Chocolate DOOM. For a list of acknowledgments,
  see <https://github.com/bradharding/doomretro/wiki/ACKNOWLEDGMENTS>.

  This file is a part of DOOM Retro.

  DOOM Retro is free software: you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the
  Free Software Foundation, either version 3 of the license, or (at your
  option) any later version.

  DOOM Retro is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with DOOM Retro. If not, see <https://www.gnu.org/licenses/>.

  DOOM is a registered trademark of id Software LLC, a ZeniMax Media
  company, in the US and/or other countries, and is used without
  permission. All other trademarks are the property of their respective
  holders. DOOM Retro is in no way affiliated with nor endorsed by
  id Software.

========================================================================
*/

#pragma once

#include "doomkeys.h"

extern int  keyboardalwaysrun;
extern int  keyboardautomap;
extern int  keyboardclearmark;
extern int  keyboardfollowmode;
extern int  keyboardgrid;
extern int  keyboardmark;
extern int  keyboardmaxzoom;
extern int  keyboardrotatemode;
extern int  keyboardzoomin;
extern int  keyboardzoomout;
extern int  keyboardback;
extern int  keyboardback2;
extern int  keyboardconsole;
extern int  keyboardfire;
extern int  keyboardforward;
extern int  keyboardforward2;
extern int  keyboardjump;
extern int  keyboardleft;
extern int  keyboardmenu;
extern int  keyboardmouselook;
extern int  keyboardnextweapon;
extern int  keyboardprevweapon;
extern int  keyboardright;
extern int  keyboardrun;
extern int  keyboardscreenshot;
extern int  keyboardstrafe;
extern int  keyboardstrafeleft2;
extern int  keyboardstrafeleft;
extern int  keyboardstraferight2;
extern int  keyboardstraferight;
extern int  keyboarduse;
extern int  keyboarduse2;
extern int  keyboardweapon1;
extern int  keyboardweapon2;
extern int  keyboardweapon3;
extern int  keyboardweapon4;
extern int  keyboardweapon5;
extern int  keyboardweapon6;
extern int  keyboardweapon7;

extern int  mouseback;
extern int  mousefire;
extern int  mouseforward;
extern int  mousejump;
extern int  mouseleft;
extern int  mousemouselook;
extern int  mousenextweapon;
extern int  mouseprevweapon;
extern int  mouseright;
extern int  mouserun;
extern int  mousescreenshot;
extern int  mousestrafe;
extern int  mousestrafeleft;
extern int  mousestraferight;
extern int  mouseuse;
extern int  mouseweapon1;
extern int  mouseweapon2;
extern int  mouseweapon3;
extern int  mouseweapon4;
extern int  mouseweapon5;
extern int  mouseweapon6;
extern int  mouseweapon7;

extern int  gamecontrolleralwaysrun;
extern int  gamecontrollerautomap;
extern int  gamecontrollerclearmark;
extern int  gamecontrollerfollowmode;
extern int  gamecontrollergrid;
extern int  gamecontrollermark;
extern int  gamecontrollermaxzoom;
extern int  gamecontrollerrotatemode;
extern int  gamecontrollerzoomin;
extern int  gamecontrollerzoomout;
extern int  gamecontrollerback;
extern int  gamecontrollerconsole;
extern int  gamecontrollerfire;
extern int  gamecontrollerforward;
extern int  gamecontrollerjump;
extern int  gamecontrollerleft;
extern int  gamecontrollermenu;
extern int  gamecontrollermouselook;
extern int  gamecontrollernextweapon;
extern int  gamecontrollerprevweapon;
extern int  gamecontrollerright;
extern int  gamecontrollerrun;
extern int  gamecontrollerstrafe;
extern int  gamecontrollerstrafeleft;
extern int  gamecontrollerstraferight;
extern int  gamecontrolleruse;
extern int  gamecontrolleruse2;
extern int  gamecontrollerweapon1;
extern int  gamecontrollerweapon2;
extern int  gamecontrollerweapon3;
extern int  gamecontrollerweapon4;
extern int  gamecontrollerweapon5;
extern int  gamecontrollerweapon6;
extern int  gamecontrollerweapon7;
